@@ -1,6 +1,6 @@
 /* FAudio - XAudio Reimplementation for FNA
  *
- * Copyright (c) 2011-2018 Ethan Lee, Luigi Auriemma, and the MonoGame Team
+ * Copyright (c) 2011-2024 Ethan Lee, Luigi Auriemma, and the MonoGame Team
  *
  * This software is provided 'as-is', without any express or implied warranty.
  * In no event will the authors be held liable for any damages arising from
@@ -64,9 +64,9 @@ typedef struct FACTOverlapped
 {
 	void *Internal; /* ULONG_PTR */
 	void *InternalHigh; /* ULONG_PTR */
-	union
+	FAUDIONAMELESS union
 	{
-		struct
+		FAUDIONAMELESS struct
 		{
 			uint32_t Offset;
 			uint32_t OffsetHigh;
@@ -101,6 +101,7 @@ typedef void (FACTCALL * FACTNotificationCallback)(
 	const FACTNotification *pNotification
 );
 
+/* FIXME: ABI bug! This should be pack(1) explicitly. Do not memcpy this! */
 typedef struct FACTRuntimeParameters
 {
 	uint32_t lookAheadTime;
@@ -167,7 +168,7 @@ typedef struct FACTWaveBankHeader
 
 typedef union FACTWaveBankMiniWaveFormat
 {
-	struct
+	FAUDIONAMELESS struct
 	{
 		uint32_t wFormatTag : 2;
 		uint32_t nChannels : 3;
@@ -180,9 +181,9 @@ typedef union FACTWaveBankMiniWaveFormat
 
 typedef struct FACTWaveBankEntry
 {
-	union
+	FAUDIONAMELESS union
 	{
-		struct
+		FAUDIONAMELESS struct
 		{
 			uint32_t dwFlags : 4;
 			uint32_t Duration : 28;
@@ -350,7 +351,7 @@ struct FACTNotification
 	uint8_t type;
 	int32_t timeStamp;
 	void *pvContext;
-	union
+	FAUDIONAMELESS union
 	{
 		FACTNotificationCue cue;
 		FACTNotificationMarker marker;
@@ -556,7 +557,7 @@ FACTAPI uint32_t FACTAudioEngine_PrepareStreamingWave(
 	FACTStreamingParameters streamingParams,
 	uint32_t dwAlignment,
 	uint32_t *pdwSeekTable, /* Optional! */
-	uint8_t *pbWaveData,
+	uint8_t *pbWaveData, /* ABI bug, do not use! */
 	uint32_t dwPlayOffset,
 	uint8_t nLoopCount,
 	FACTWave **ppWave
